Class: Jekyll::Post

Inherits:
Object
  • Object
show all
Includes:
Comparable, Convertible
Defined in:
lib/jekyll/post.rb

Constant Summary collapse

MATCHER =
/^(.+\/)*(\d+-\d+-\d+)-(.*)(\.[^.]+)$/

Class Attribute Summary collapse

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Convertible

#converter, #do_layout, #output_ext, #read_yaml, #to_s, #transform

Constructor Details

#initialize(site, source, dir, name) ⇒ Post

Initialize this Post instance. site is the Site base is the String path to the dir containing the post file name is the String filename of the post file categories is an Array of Strings for the categories for this post

Returns



34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/jekyll/post.rb', line 34

def initialize(site, source, dir, name)
  @site = site
  @base = File.join(source, dir, '_posts')
  @name = name

  self.categories = dir.split('/').reject { |x| x.empty? }
  self.process(name)
  self.read_yaml(@base, name)

  #If we've added a date and time to the yaml, use that instead of the filename date
  #Means we'll sort correctly.
  if self.data.has_key?('date')
    # ensure Time via to_s and reparse
    self.date = Time.parse(self.data["date"].to_s)
  end

  if self.data.has_key?('published') && self.data['published'] == false
    self.published = false
  else
    self.published = true
  end

  self.tags = self.data.pluralized_array("tag", "tags")

  if self.categories.empty?
    self.categories = self.data.pluralized_array('category', 'categories')
  end
end

Class Attribute Details

.lsiObject

Returns the value of attribute lsi.



8
9
10
# File 'lib/jekyll/post.rb', line 8

def lsi
  @lsi
end

Instance Attribute Details

#categoriesObject

Returns the value of attribute categories.



23
24
25
# File 'lib/jekyll/post.rb', line 23

def categories
  @categories
end

#contentObject

Returns the value of attribute content.



22
23
24
# File 'lib/jekyll/post.rb', line 22

def content
  @content
end

#dataObject

Returns the value of attribute data.



22
23
24
# File 'lib/jekyll/post.rb', line 22

def data
  @data
end

#dateObject

Returns the value of attribute date.



23
24
25
# File 'lib/jekyll/post.rb', line 23

def date
  @date
end

#extObject

Returns the value of attribute ext.



22
23
24
# File 'lib/jekyll/post.rb', line 22

def ext
  @ext
end

#nameObject (readonly)

Returns the value of attribute name.



25
26
27
# File 'lib/jekyll/post.rb', line 25

def name
  @name
end

#outputObject

Returns the value of attribute output.



22
23
24
# File 'lib/jekyll/post.rb', line 22

def output
  @output
end

#publishedObject

Returns the value of attribute published.



23
24
25
# File 'lib/jekyll/post.rb', line 23

def published
  @published
end

#siteObject

Returns the value of attribute site.



21
22
23
# File 'lib/jekyll/post.rb', line 21

def site
  @site
end

#slugObject

Returns the value of attribute slug.



23
24
25
# File 'lib/jekyll/post.rb', line 23

def slug
  @slug
end

#tagsObject

Returns the value of attribute tags.



23
24
25
# File 'lib/jekyll/post.rb', line 23

def tags
  @tags
end

Class Method Details

.valid?(name) ⇒ Boolean

Post name validator. Post filenames must be like:

2008-11-05-my-awesome-post.textile

Returns

Returns:

  • (Boolean)


17
18
19
# File 'lib/jekyll/post.rb', line 17

def self.valid?(name)
  name =~ MATCHER
end

Instance Method Details

#<=>(other) ⇒ Object

Spaceship is based on Post#date, slug

Returns -1, 0, 1



66
67
68
69
70
71
72
# File 'lib/jekyll/post.rb', line 66

def <=>(other)
  cmp = self.date <=> other.date
  if 0 == cmp
   cmp = self.slug <=> other.slug
  end
  return cmp
end

#destination(dest) ⇒ Object

Obtain destination path. dest is the String path to the destination dir

Returns destination file path.



198
199
200
201
202
203
# File 'lib/jekyll/post.rb', line 198

def destination(dest)
  # The url needs to be unescaped in order to preserve the correct filename
  path = File.join(dest, CGI.unescape(self.url))
  path = File.join(path, "index.html") if template[/\.html$/].nil?
  path
end

#dirObject

The generated directory into which the post will be placed upon generation. This is derived from the permalink or, if permalink is absent, set to the default date e.g. "/2008/11/05/" if the permalink style is :date, otherwise nothing

Returns



93
94
95
# File 'lib/jekyll/post.rb', line 93

def dir
  File.dirname(url)
end

#idObject

The UID for this post (useful in feeds) e.g. /2008/11/05/my-awesome-post

Returns



153
154
155
# File 'lib/jekyll/post.rb', line 153

def id
  File.join(self.dir, self.slug)
end

#inspectObject



233
234
235
# File 'lib/jekyll/post.rb', line 233

def inspect
  "<Post: #{self.id}>"
end

#nextObject



237
238
239
240
241
242
243
244
245
# File 'lib/jekyll/post.rb', line 237

def next
  pos = self.site.posts.index(self)

  if pos && pos < self.site.posts.length-1
    self.site.posts[pos+1]
  else
    nil
  end
end

The full path and filename of the post. Defined in the YAML of the post body (Optional)

Returns



102
103
104
# File 'lib/jekyll/post.rb', line 102

def permalink
  self.data && self.data['permalink']
end

#previousObject



247
248
249
250
251
252
253
254
# File 'lib/jekyll/post.rb', line 247

def previous
  pos = self.site.posts.index(self)
  if pos && pos > 0
    self.site.posts[pos-1]
  else
    nil
  end
end

#process(name) ⇒ Object

Extract information from the post filename name is the String filename of the post file

Returns nothing



78
79
80
81
82
83
84
85
# File 'lib/jekyll/post.rb', line 78

def process(name)
  m, cats, date, slug, ext = *name.match(MATCHER)
  self.date = Time.parse(date)
  self.slug = slug
  self.ext = ext
rescue ArgumentError
  raise FatalException.new("Post #{name} does not have a valid date.")
end

Calculate related posts.

Returns []



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/jekyll/post.rb', line 160

def related_posts(posts)
  return [] unless posts.size > 1

  if self.site.lsi
    self.class.lsi ||= begin
      puts "Running the classifier... this could take a while."
      lsi = Classifier::LSI.new
      posts.each { |x| $stdout.print(".");$stdout.flush;lsi.add_item(x) }
      puts ""
      lsi
    end

    related = self.class.lsi.find_related(self.content, 11)
    related - [self]
  else
    (posts - [self])[0..9]
  end
end

#render(layouts, site_payload) ⇒ Object

Add any necessary layouts to this post layouts is a Hash of => "layout" site_payload is the site payload hash

Returns nothing



184
185
186
187
188
189
190
191
192
# File 'lib/jekyll/post.rb', line 184

def render(layouts, site_payload)
  # construct payload
  payload = {
    "site" => { "related_posts" => related_posts(site_payload["site"]["posts"]) },
    "page" => self.to_liquid
  }.deep_merge(site_payload)

  do_layout(payload, layouts)
end

#templateObject



106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/jekyll/post.rb', line 106

def template
  case self.site.permalink_style
  when :pretty
    "/:categories/:year/:month/:day/:title/"
  when :none
    "/:categories/:title.html"
  when :date
    "/:categories/:year/:month/:day/:title.html"
  else
    self.site.permalink_style.to_s
  end
end

#to_liquidObject

Convert this post into a Hash for use in Liquid templates.

Returns



220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/jekyll/post.rb', line 220

def to_liquid
  self.data.deep_merge({
    "title"      => self.data["title"] || self.slug.split('-').select {|w| w.capitalize! || w }.join(' '),
    "url"        => self.url,
    "date"       => self.date,
    "id"         => self.id,
    "categories" => self.categories,
    "next"       => self.next,
    "previous"   => self.previous,
    "tags"       => self.tags,
    "content"    => self.content })
end

#urlObject

The generated relative url of this post e.g. /2008/11/05/my-awesome-post.html

Returns



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/jekyll/post.rb', line 123

def url
  return @url if @url

  url = if permalink
    permalink
  else
    {
      "year"       => date.strftime("%Y"),
      "month"      => date.strftime("%m"),
      "day"        => date.strftime("%d"),
      "title"      => CGI.escape(slug),
      "i_day"      => date.strftime("%d").to_i.to_s,
      "i_month"    => date.strftime("%m").to_i.to_s,
      "categories" => categories.map { |c| URI.escape(c) }.join('/'),
      "output_ext" => self.output_ext
    }.inject(template) { |result, token|
      result.gsub(/:#{Regexp.escape token.first}/, token.last)
    }.gsub(/\/\//, "/")
  end

  # sanitize url
  @url = url.split('/').reject{ |part| part =~ /^\.+$/ }.join('/')
  @url += "/" if url =~ /\/$/
  @url
end

#write(dest) ⇒ Object

Write the generated post file to the destination directory. dest is the String path to the destination dir

Returns nothing



209
210
211
212
213
214
215
# File 'lib/jekyll/post.rb', line 209

def write(dest)
  path = destination(dest)
  FileUtils.mkdir_p(File.dirname(path))
  File.open(path, 'w') do |f|
    f.write(self.output)
  end
end